@@ -5,7 +5,7 @@ use lib qw( ../../../../lib );
 
 =head1 NAME
 
-Algorithm::Evolutionary::Fitness::Rastrigin - Implementation of Rastrigin's function
+    Algorithm::Evolutionary::Fitness::Rastrigin - Implementation of Rastrigin's function
 
 =head1 SYNOPSIS
 
@@ -14,8 +14,8 @@ Algorithm::Evolutionary::Fitness::Rastrigin - Implementation of Rastrigin's func
 
 =head1 DESCRIPTION
 
-Classical Rastrigin function, used for tests of numerical optimization problems. 
-Check it at L<http://www-optima.amp.i.kyoto-u.ac.jp/member/student/hedar/Hedar_files/TestGO_files/Page2607.htm>
+    Classical Rastrigin function, used for tests of numerical optimization problems. 
+Check it at http://www-optima.amp.i.kyoto-u.ac.jp/member/student/hedar/Hedar_files/TestGO_files/Page2607.htm
 
 =head1 METHODS
 
@@ -23,16 +23,15 @@ Check it at L<http://www-optima.amp.i.kyoto-u.ac.jp/member/student/hedar/Hedar_f
 
 package Algorithm::Evolutionary::Fitness::Rastrigin;
 
-our ($VERSION) = ( '$Revision: 3.3 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.1 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use Carp qw( croak );
 use base qw(Algorithm::Evolutionary::Fitness::Base);
-use constant PI2    => 8 * atan2(1, 1);
-use constant RASTRIGIN_A => 10;
+use constant PI2    => 2 * atan2(1, 1);
 
 =head2 new
 
-Creates a new instance of the problem, with the said number of bits and peaks
+    Creates a new instance of the problem, with the said number of bits and peaks
 
 =cut 
 
@@ -45,7 +44,7 @@ sub new {
 
   #Assign stuff
   $self->{'n_dimensions'} = $n_dimensions;
-  $self->{'_base_fitness'} = RASTRIGIN_A*$n_dimensions;
+  $self->{'_base_fitness'} = 10*$n_dimensions;
   $self->initialize();
   return $self;
 }
@@ -57,7 +56,7 @@ sub _really_apply {
 
 =head2 Rastrigin
 
-Applies the knapsack problem to the string, using a penalty function
+    Applies the knapsack problem to the string, using a penalty function
 
 =cut
 
@@ -66,7 +65,7 @@ sub Rastrigin {
     my @array = @_;
     my $fitness = $self->{'_base_fitness'};
     for ( my $i = 0; $i < $self->{'n_dimensions'}; $i ++ ) {
-      $fitness += $array[$i]*$array[$i]- RASTRIGIN_A *cos(PI2*$array[$i]);
+      $fitness += $array[$i]-cos(PI2*$array[$i]);
     }
     return $fitness;
 }
@@ -77,10 +76,10 @@ sub Rastrigin {
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2010/09/28 19:41:26 $ 
-  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/Rastrigin.pm,v 3.3 2010/09/28 19:41:26 jmerelo Exp $ 
+  CVS Info: $Date: 2010/09/24 08:39:07 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Fitness/Rastrigin.pm,v 3.1 2010/09/24 08:39:07 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.3 $
+  $Revision: 3.1 $
   $Name $
 
 =cut
