@@ -4,19 +4,17 @@ use warnings;
 =head1 NAME
 
 Algorithm::Evolutionary::Op::Canonical_GA_NN - Canonical Genetic
-                 Algorithm that does not rank population
+                 Algorithm that does not compute or order population
 
 =head1 SYNOPSIS
 
   # Straightforward instance, with all defaults (except for fitness function)
-  my $algo = new Algorithm::Evolutionary::Op::Canonical_GA_NN; 
+  my $algo = new Algorithm::Evolutionary::Op::Canonical_GA_NN( $eval ); 
 
   #Define an easy single-generation algorithm with predefined mutation and crossover
   my $m = new Algorithm::Evolutionary::Op::Bitflip; #Changes a single bit
   my $c = new Algorithm::Evolutionary::Op::QuadXOver; #Classical 2-point crossover
-  my $generation = new Algorithm::Evolutionary::Op::Canonical_GA_NN( 0.2, [$m, $c] );
-
-   my $generation = new Algorithm::Evolutionary::Op::Canonical_GA_NN( undef , [$m, $c] ); # Defaults to 0.4
+  my $generation = new Algorithm::Evolutionary::Op::Canonical_GA_NN( $rr, 0.2, [$m, $c] );
 
 =head1 Base Class
 
@@ -33,10 +31,6 @@ The first operator should be unary (a la mutation) and the second
 binary (a la crossover) they will be applied in turn to couples of the
 population.
 
-This is a fast version of the canonical GA, useful for large
-populations, since it avoids the expensive rank operation. Roulette
-wheel selection, still, is kind of slow.
-
 =head1 METHODS
 
 =cut
@@ -45,9 +39,11 @@ package Algorithm::Evolutionary::Op::Canonical_GA_NN;
 
 use lib qw(../../..);
 
-our $VERSION =   "3.6";
+our $VERSION =   sprintf "%d.%03d", q$Revision: 3.2 $ =~ /(\d+)\.(\d+)/g; 
+
 
 use Carp;
+use Clone::Fast qw(clone);
 
 use Algorithm::Evolutionary qw(Wheel
 			       Op::Bitflip
@@ -61,12 +57,10 @@ our $ARITY = 1;
 
 =head2 new( [ $selection_rate][,$operators_ref_to_array] )
 
-Creates an algorithm, with the usual operators. Includes a default
-mutation and crossover, in case they are not passed as parameters. The
-first element in the array ref should be an unary, and the second a
-binary operator. This binary operator must accept parameters by
-reference, not value; it will modify them. For the time being, just
-L<Algorithm::Evolutionary::Op::QuadXOver> works that way. 
+Creates an algorithm, with the usual operators. Includes a default mutation
+and crossover, in case they are not passed as parameters. The first
+    element in the array ref should be an unary, and the second a
+    binary operator.
 
 =cut
 
@@ -92,7 +86,7 @@ sub new {
 
 Applies a single generation of the algorithm to the population; checks
 that it receives a ref-to-array as input, croaks if it does not. This
-population should be already evaluated. Returns a new population for
+population whould be already evaluated. Returns a new population for
 next generation, unsorted.
 
 =cut
@@ -102,6 +96,8 @@ sub apply ($) {
   my $pop = shift || croak "No population here";
   croak "Incorrect type ".(ref $pop) if  ref( $pop ) ne $APPLIESTO;
 
+  my $eval = $self->{_eval};
+
   my @newPop;
   @$pop = sort { $b->{_fitness} <=> $a->{_fitness} } @$pop;
   my @rates = map( $_->Fitness(), @$pop );
@@ -138,11 +134,9 @@ sub apply ($) {
 
 =item L<Algorithm::Evolutionary::Fitness::Base>
 
-=item Of course, L<Algorithm::Evolutionary::Fitness::CanonicalGA>
-
 =back
 
-You will also find a
+Probably you will also be able to find a
     L<canonical-genetic-algorithm.pl> example within this
     bundle. Check it out for usage examples
 
@@ -151,6 +145,12 @@ You will also find a
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
+  CVS Info: $Date: 2010/01/17 19:08:29 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/Canonical_GA_NN.pm,v 3.2 2010/01/17 19:08:29 jmerelo Exp $ 
+  $Author: jmerelo $ 
+  $Revision: 3.2 $
+  $Name $
+
 =cut
 
 "The truth is out there";
